# wikidata-fast-query

[![PyPI version](https://img.shields.io/pypi/v/wikidata-fast-query.svg)](https://pypi.org/project/wikidata-fast-query/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/wikidata-fast-query.svg)](https://pypi.org/project/wikidata-fast-query/)
[![PyPI license](https://img.shields.io/pypi/l/wikidata-fast-query.svg)](https://pypi.org/project/wikidata-fast-query/)
